"""
Dungeon Master core functionality.

This package contains the core functionality modules for Dungeon Master,
including decorator parsing, template handling, validation logic, and git utilities.
"""

# Core functionality will be imported as needed by individual modules
# to avoid circular imports

__all__ = ["decorator_parser", "template", "validation", "git_utils"]
