"""
Dungeon Master git hooks.

This package contains git hook implementations, primarily the pre-commit hook
that enforces documentation requirements.
"""

# Hook modules will be imported as needed

__all__ = ["pre_commit"]
